@@ -5,14 +5,19 @@ from .validate import validate
 from .dumpers import dump_to_path, dump_to_zip, dump_to_sql
 
 from .add_computed_field import add_computed_field
-from .cache import cache
+from .add_field import add_field
+from .checkpoint import checkpoint
 from .concatenate import concatenate
 from .delete_fields import delete_fields
 from .duplicate import duplicate
 from .filter_rows import filter_rows
 from .find_replace import find_replace
-from .join import join, join_self
+from .join import join, join_self, join_with_self
+from .select_fields import select_fields
+from .set_primary_key import set_primary_key
 from .sort_rows import sort_rows
+from .stream import stream
 from .unpivot import unpivot
+from .unstream import unstream
 from .update_package import update_package, add_metadata
 from .update_resource import update_resource
