@@ -4,11 +4,9 @@ import os
 import isodate
 import logging
 
-from tableschema import Field
-
 
 DATE_FORMAT = '%Y-%m-%d'
-DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
+DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
 TIME_FORMAT = '%H:%M:%S'
 
 
@@ -34,9 +32,8 @@ class FileFormat():
 
     @classmethod
     def prepare_resource(cls, resource):
-        field: Field = None
-        for field in resource.schema.fields:
-            field.descriptor.update(cls.PYTHON_DIALECT.get(field.type, {}))
+        for field in resource.descriptor['schema']['fields']:
+            field.update(cls.PYTHON_DIALECT.get(field['type'], {}))
 
     def __transform_row(self, row):
         try:
@@ -61,6 +58,16 @@ class FileFormat():
         self.write_transformed_row(transformed_row)
 
 
+class CsvTitlesDictWriter(csv.DictWriter):
+    def __init__(self, *args, **kwargs):
+        self.fieldtitles = kwargs.pop('fieldtitles')
+        super().__init__(*args, **kwargs)
+
+    def writeheader(self):
+        header = dict(zip(self.fieldnames, self.fieldtitles))
+        self.writerow(header)
+
+
 class CSVFormat(FileFormat):
 
     SERIALIZERS = {
@@ -94,9 +101,13 @@ class CSVFormat(FileFormat):
         },
     }
 
-    def __init__(self, file, schema):
+    def __init__(self, file, schema, use_titles=False):
         headers = [f.name for f in schema.fields]
-        csv_writer = csv.DictWriter(file, headers)
+        if use_titles:
+            titles = [f.descriptor.get('title', f.name) for f in schema.fields]
+            csv_writer = CsvTitlesDictWriter(file, headers, fieldtitles=titles)
+        else:
+            csv_writer = csv.DictWriter(file, headers)
         csv_writer.writeheader()
         super(CSVFormat, self).__init__(csv_writer, schema)
 
@@ -104,7 +115,7 @@ class CSVFormat(FileFormat):
     def prepare_resource(cls, resource):
         descriptor = resource.descriptor
         descriptor['encoding'] = 'utf-8'
-        basename, _ = os.path.splitext(resource.source)
+        basename, _ = os.path.splitext(descriptor['path'])
         descriptor['path'] = basename + '.csv'
         descriptor['format'] = 'csv'
         descriptor['dialect'] = dict(
